.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`measure`
======================
.. automodule:: skimage.measure

.. currentmodule:: skimage.measure
.. autosummary::

   skimage.measure.find_contours
   skimage.measure.regionprops
   skimage.measure.perimeter
   skimage.measure.approximate_polygon
   skimage.measure.subdivide_polygon
   skimage.measure.ransac
   skimage.measure.block_reduce
   skimage.measure.moments
   skimage.measure.moments_central
   skimage.measure.moments_coords
   skimage.measure.moments_hu
   skimage.measure.marching_cubes_lewiner
   skimage.measure.marching_cubes_classic
   skimage.measure.mesh_surface_area
   skimage.measure.correct_mesh_orientation
   skimage.measure.profile_line
   skimage.measure.label
   skimage.measure.points_in_poly
   skimage.measure.grid_points_in_poly
   skimage.measure.compare_ssim
   skimage.measure.compare_mse
   skimage.measure.compare_nrmse
   skimage.measure.compare_psnr
   skimage.measure.shannon_entropy

   skimage.measure.LineModelND
   skimage.measure.CircleModel
   skimage.measure.EllipseModel


find_contours
-------------

.. autofunction:: skimage.measure.find_contours

regionprops
-----------

.. autofunction:: skimage.measure.regionprops

perimeter
---------

.. autofunction:: skimage.measure.perimeter

approximate_polygon
-------------------

.. autofunction:: skimage.measure.approximate_polygon

subdivide_polygon
-----------------

.. autofunction:: skimage.measure.subdivide_polygon

ransac
------

.. autofunction:: skimage.measure.ransac

block_reduce
------------

.. autofunction:: skimage.measure.block_reduce

moments
-------

.. autofunction:: skimage.measure.moments

moments_central
---------------

.. autofunction:: skimage.measure.moments_central

moments_coords
--------------

.. autofunction:: skimage.measure.moments_coords

moments_hu
----------

.. autofunction:: skimage.measure.moments_hu

marching_cubes_lewiner
----------------------

.. autofunction:: skimage.measure.marching_cubes_lewiner

marching_cubes_classic
----------------------

.. autofunction:: skimage.measure.marching_cubes_classic

mesh_surface_area
-----------------

.. autofunction:: skimage.measure.mesh_surface_area

correct_mesh_orientation
------------------------

.. autofunction:: skimage.measure.correct_mesh_orientation

profile_line
------------

.. autofunction:: skimage.measure.profile_line

label
-----

.. autofunction:: skimage.measure.label

points_in_poly
--------------

.. autofunction:: skimage.measure.points_in_poly

grid_points_in_poly
-------------------

.. autofunction:: skimage.measure.grid_points_in_poly

compare_ssim
------------

.. autofunction:: skimage.measure.compare_ssim

compare_mse
-----------

.. autofunction:: skimage.measure.compare_mse

compare_nrmse
-------------

.. autofunction:: skimage.measure.compare_nrmse

compare_psnr
------------

.. autofunction:: skimage.measure.compare_psnr

shannon_entropy
---------------

.. autofunction:: skimage.measure.shannon_entropy


:class:`LineModelND`
--------------------


.. autoclass:: LineModelND
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

:class:`CircleModel`
--------------------


.. autoclass:: CircleModel
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

:class:`EllipseModel`
---------------------


.. autoclass:: EllipseModel
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__
